==> omnisaude_chatbot-0.0.5%2B2.tar.gz: lib/app/chatbot/file_content/file_content_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_cached_pdfview/flutter_cached_pdfview.dart';
import 'package:mime/mime.dart';
import 'package:url_launcher/url_launcher.dart';

import '../../core/models/file_content_model.dart';
import '../../core/models/ws_message_model.dart';
import '../../core/services/view_document_service.dart';
import '../../core/services/view_photo_service.dart';
import '../../shared/image/image_widget.dart';
import '../../shared/loading/loading_widget.dart';

class FileContentWidget extends StatefulWidget {
  final WsMessage message;

  const FileContentWidget({Key key, @required this.message}) : super(key: key);

  @override
  _FileContentWidgetState createState() => _FileContentWidgetState();
}

class _FileContentWidgetState extends State<FileContentWidget>
    with AutomaticKeepAliveClientMixin {
  @override
  bool get wantKeepAlive => true;

  @override
  // ignore: must_call_super
  Widget build(BuildContext context) {
    final FileContent _message = widget.message.fileContent;
    final String _mimeType = lookupMimeType(_message.value);

    if (lookupMimeType(_message.value).contains("image")) {
      return _imageContent(_message.value, _message.name, _message.comment);
    } else if (_mimeType == "application/pdf") {
      return _pdfContent(_message.value, _message.name, _message.comment);
    }
    return _anyContent(_message.value, _message.name, _message.comment);
  }

  Widget _imageContent(String url, String filename, String comment) {
    return Container(
      constraints: const BoxConstraints(maxWidth: 300.0, maxHeight: 200.0),
      padding: const EdgeInsets.all(5.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: [
          Expanded(
            child: GestureDetector(
              onTap: () async {
                final ViewPhotoService _viewPhotoService = ViewPhotoService();
                await _viewPhotoService.onViewSinglePhoto(context, url);
              },
              child: Container(
                decoration: BoxDecoration(
                  color: Theme.of(context).canvasColor.withOpacity(0.25),
                  borderRadius: BorderRadius.circular(15.0),
                ),
                child: ImageWidget(url: url, fit: BoxFit.cover, radius: 15.0),
              ),
            ),
          ),
          _commentContent(comment),
        ],
      ),
    );
  }

  Widget _pdfContent(String url, String filename, String comment) {
    return Container(
      constraints: const BoxConstraints(maxWidth: 300.0, maxHeight: 200.0),
      decoration: BoxDecoration(
          border: Border.all(color: Theme.of(context).primaryColor)),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: [
          Expanded(
            child: GestureDetector(
              onTap: () async {
                final ViewDocumentService _service = ViewDocumentService();
                await _service.onViewSingleDocument(context, url);
              },
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: [
                  Expanded(
                    child: Stack(
                      children: [
                        ClipRRect(
                          borderRadius: BorderRadius.only(
                            topLeft: Radius.circular(20.0),
                            topRight: Radius.circular(20.0),
                          ),
                          child: PDF(fitEachPage: true, autoSpacing: false)
                              .fromUrl(
                            url,
                            placeholder: (double progress) {
                              return LoadingWidget(
                                message: "Carregando documento",
                                background: Theme.of(context).primaryColor,
                                radius: 20.0,
                                margin: 20.0,
                                padding: 20.0,
                              );
                            },
                          ),
                        ),
                        Container(color: Colors.transparent),
                      ],
                    ),
                  ),
                  Container(
                    padding: EdgeInsets.all(10.0),
                    child: Row(
                      children: [
                        Icon(Icons.insert_drive_file_rounded),
                        SizedBox(width: 10.0),
                        Expanded(
                          child: Text(
                            "$filename",
                            overflow: TextOverflow.ellipsis,
                          ),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          ),
          _commentContent(comment),
        ],
      ),
    );
  }

  Widget _anyContent(String url, String filename, String comment) {
    return Container(
      constraints: const BoxConstraints(maxWidth: 300.0, maxHeight: 200.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        mainAxisSize: MainAxisSize.min,
        children: [
          GestureDetector(
            onTap: () async {
              await launch(url, forceWebView: true, enableJavaScript: true);
            },
            child: Container(
              padding: EdgeInsets.all(10.0),
              color: Theme.of(context).cardColor,
              child: Row(
                children: [
                  Icon(Icons.insert_drive_file_rounded),
                  SizedBox(width: 10.0),
                  Expanded(
                    child: Text(
                      "$filename",
                      overflow: TextOverflow.ellipsis,
                    ),
                  ),
                  SizedBox(width: 10.0),
                  Icon(Icons.download_rounded),
                ],
              ),
            ),
          ),
          _commentContent(comment),
        ],
      ),
    );
  }

  Widget _commentContent(String comment) {
    if (comment == null)
      return Container();
    else if (comment.trim().isEmpty) return Container();
    return SelectableText(comment);
  }
}

==> omnisaude_chatbot-0.0.6-dev.2%2B2.tar.gz: lib/app/chatbot/file_content/file_content_widget.dart <==
import 'package:flutter/material.dart';
import 'package:mime/mime.dart';
import 'package:url_launcher/url_launcher.dart';

import '../../core/models/file_content_model.dart';
import '../../core/models/ws_message_model.dart';
import '../../core/services/view_photo_service.dart';
import '../../shared/image/image_widget.dart';

class FileContentWidget extends StatefulWidget {
  final WsMessage message;

  const FileContentWidget({Key key, @required this.message}) : super(key: key);

  @override
  _FileContentWidgetState createState() => _FileContentWidgetState();
}

class _FileContentWidgetState extends State<FileContentWidget> {
  @override
  Widget build(BuildContext context) {
    final FileContent _message = widget.message.fileContent;
    final String _mimeType = lookupMimeType(_message.value);

    if (lookupMimeType(_message.value).contains("image")) {
      return _imageContent(_message.value, _message.name, _message.comment);
    } else if (_mimeType == "application/pdf") {
        return _anyContent(_message.value, _message.name, _message.comment);
    }
    return _anyContent(_message.value, _message.name, _message.comment);
  }

  Widget _imageContent(String url, String filename, String comment) {
    return Container(
      constraints: const BoxConstraints(maxWidth: 300.0, maxHeight: 200.0),
      padding: const EdgeInsets.all(5.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: [
          Expanded(
            child: GestureDetector(
              onTap: () {
                final ViewPhotoService _viewPhotoService = ViewPhotoService();
                _viewPhotoService.onViewSinglePhoto(context, url);
                _viewPhotoService.dispose();
              },
              child: ImageWidget(
                url: url,
                fit: BoxFit.cover,
                radius: 20.0,
              ),
            ),
          ),
          _commentContent(comment),
        ],
      ),
    );
  }

  Widget _anyContent(String url, String filename, String comment) {
    return Container(
      constraints: const BoxConstraints(maxWidth: 300.0, maxHeight: 200.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        mainAxisSize: MainAxisSize.min,
        children: [
          GestureDetector(
            onTap: () async {
              await launch(url, forceWebView: true, enableJavaScript: true);
            },
            child: Container(
              padding: EdgeInsets.all(10.0),
              color: Theme.of(context).cardColor,
              child: Row(
                children: [
                  Icon(Icons.insert_drive_file_rounded),
                  SizedBox(width: 10.0),
                  Expanded(
                    child: Text(
                      "$filename",
                      overflow: TextOverflow.ellipsis,
                    ),
                  ),
                  SizedBox(width: 10.0),
                  Icon(Icons.download_rounded),
                ],
              ),
            ),
          ),
          _commentContent(comment),
        ],
      ),
    );
  }

  Widget _commentContent(String comment) {
    if (comment == null)
      return Container();
    else if (comment.trim().isEmpty) return Container();
    return SelectableText(comment);
  }
}
